==> devops-client-java-1.0.0-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineStatusFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import org.joda.time.DateTime;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public interface V1alpha1PipelineStatusFluent<A extends V1alpha1PipelineStatusFluent<A>> extends Fluent<A>{


    public Boolean isAborted();
    public A withAborted(Boolean aborted);
    public Boolean hasAborted();
    public A withNewAborted(String arg1);
    public A withNewAborted(boolean arg1);
    public DateTime getFinishedAt();
    public A withFinishedAt(DateTime finishedAt);
    public Boolean hasFinishedAt();
    public A withNewFinishedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewFinishedAt(Object arg0);
    public A withNewFinishedAt(long arg0);
    
/**
 * This method has been deprecated, please use method buildJenkins instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStatusJenkins getJenkins();
    public V1alpha1PipelineStatusJenkins buildJenkins();
    public A withJenkins(V1alpha1PipelineStatusJenkins jenkins);
    public Boolean hasJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> withNewJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> withNewJenkinsLike(V1alpha1PipelineStatusJenkins item);
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editOrNewJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editOrNewJenkinsLike(V1alpha1PipelineStatusJenkins item);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public DateTime getStartedAt();
    public A withStartedAt(DateTime startedAt);
    public Boolean hasStartedAt();
    public A withNewStartedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewStartedAt(Object arg0);
    public A withNewStartedAt(long arg0);
    public DateTime getUpdatedAt();
    public A withUpdatedAt(DateTime updatedAt);
    public Boolean hasUpdatedAt();
    public A withNewUpdatedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewUpdatedAt(Object arg0);
    public A withNewUpdatedAt(long arg0);

    public interface JenkinsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStatusJenkinsFluent<V1alpha1PipelineStatusFluent.JenkinsNested<N>>{

        
    public N and();    public N endJenkins();
}


}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineStatusFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import org.joda.time.DateTime;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public interface V1alpha1PipelineStatusFluent<A extends V1alpha1PipelineStatusFluent<A>> extends Fluent<A>{


    public Boolean isAborted();
    public A withAborted(Boolean aborted);
    public Boolean hasAborted();
    public A withNewAborted(String arg1);
    public A withNewAborted(boolean arg1);
    public DateTime getFinishedAt();
    public A withFinishedAt(DateTime finishedAt);
    public Boolean hasFinishedAt();
    public A withNewFinishedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewFinishedAt(Object arg0);
    public A withNewFinishedAt(long arg0);
    
/**
 * This method has been deprecated, please use method buildInformation instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStatusInfo getInformation();
    public V1alpha1PipelineStatusInfo buildInformation();
    public A withInformation(V1alpha1PipelineStatusInfo information);
    public Boolean hasInformation();
    public V1alpha1PipelineStatusFluent.InformationNested<A> withNewInformation();
    public V1alpha1PipelineStatusFluent.InformationNested<A> withNewInformationLike(V1alpha1PipelineStatusInfo item);
    public V1alpha1PipelineStatusFluent.InformationNested<A> editInformation();
    public V1alpha1PipelineStatusFluent.InformationNested<A> editOrNewInformation();
    public V1alpha1PipelineStatusFluent.InformationNested<A> editOrNewInformationLike(V1alpha1PipelineStatusInfo item);
    
/**
 * This method has been deprecated, please use method buildJenkins instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStatusJenkins getJenkins();
    public V1alpha1PipelineStatusJenkins buildJenkins();
    public A withJenkins(V1alpha1PipelineStatusJenkins jenkins);
    public Boolean hasJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> withNewJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> withNewJenkinsLike(V1alpha1PipelineStatusJenkins item);
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editOrNewJenkins();
    public V1alpha1PipelineStatusFluent.JenkinsNested<A> editOrNewJenkinsLike(V1alpha1PipelineStatusJenkins item);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public DateTime getStartedAt();
    public A withStartedAt(DateTime startedAt);
    public Boolean hasStartedAt();
    public A withNewStartedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewStartedAt(Object arg0);
    public A withNewStartedAt(long arg0);
    public DateTime getUpdatedAt();
    public A withUpdatedAt(DateTime updatedAt);
    public Boolean hasUpdatedAt();
    public A withNewUpdatedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewUpdatedAt(Object arg0);
    public A withNewUpdatedAt(long arg0);

    public interface InformationNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStatusInfoFluent<V1alpha1PipelineStatusFluent.InformationNested<N>>{

        
    public N and();    public N endInformation();
}
    public interface JenkinsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStatusJenkinsFluent<V1alpha1PipelineStatusFluent.JenkinsNested<N>>{

        
    public N and();    public N endJenkins();
}


}
